Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.transformation.mimlTOmi.label_powerset_transformation.LabelPowersetTransformation

  Bases: `object`

  Class that performs a label powerset transformation.

  transform_bag(bag: Bag) → Bag

    Transform miml bag to multi instance bags

    # Parameters

    bag :

      Bag to be transformed to multi-instance bag

    # Returns

    bagslist[Bag]

      List of n_labels transformed bags

  transform_dataset(dataset: MIMLDataset) → MIMLDataset

    Transform the dataset to multi-instance datasets dividing the original dataset into n datasets with a single label, where n is the number of labels.

    # Returns

    datasets: MIMLDataset

      Multi instance dataset